@@ -1,4 +1,4 @@
-// $Id: main_thread.c,v 1.10 2006/03/19 20:17:14 khlut Exp $
+// $Id: main_thread.c,v 1.11 2006/03/28 20:00:54 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -265,7 +265,7 @@ char *NP_GetMIMEDescription(void)
 NPError NP_GetValue(void *future, NPPVariable variable, void *value)
 {
   NPError err = NPERR_NO_ERROR;
-  Debug("NP_GETVALUE\n");
+  Debug("NP_GETVALUE %d\n",(unsigned)variable);
   switch (variable) {
     case NPPVpluginNameString:
       *((char **) value) = "The GenReS Mozilla plugin V " RELEASE;
