@@ -1,4 +1,4 @@
-// $Id: slavesdir.c,v 1.1.1.1 2005/11/04 09:07:01 khlut Exp $
+// $Id: slavesdir.c,v 1.2 2006/03/28 20:00:54 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -44,7 +44,7 @@ int listdir(char **list, int *listlen,
     struct stat st;
     int listmax= (*listlen+PSIZE) & ~(PSIZE-1);
     
-    *path=realloc(*path, pathlen+subdirlen+NAME_MAX+2);	if(!*path){perror("realloc"); return -1;}
+    *path=PR_Realloc(*path, pathlen+subdirlen+NAME_MAX+2);	if(!*path){perror("realloc"); return -1;}
     (*path)[pathlen+subdirlen]=0;
     dir = opendir(*path);	if(!dir) { perror(*path); return 0; }
     while(( de=readdir(dir) )) {
@@ -60,7 +60,7 @@ int listdir(char **list, int *listlen,
 	    if(strstr(*list,*path+pathlen)) continue;
 	    if(*listlen+subdirlen+namelen+4 > listmax) {
 		listmax= (*listlen+subdirlen+namelen+3+PSIZE) & ~(PSIZE-1);
-		*list=realloc(*list, listmax);	if(!*list) {perror("realloc"); break;}
+		*list=PR_Realloc(*list, listmax);	if(!*list) {perror("realloc"); break;}
 	    }
 	    strcpy(*list+*listlen, *path+pathlen);
 	    *listlen+=subdirlen+namelen;
@@ -80,12 +80,12 @@ char *strpath(char *_path)
 
     if(_path[0]=='~') {
 	char *home=getenv("HOME");	if(!home) return 0;
-	path=malloc(strlen(_path)+strlen(home)+NAME_MAX);	if(!path) return 0;
+	path=PR_Malloc(strlen(_path)+strlen(home)+NAME_MAX);	if(!path) return 0;
         strcpy(path, home);
 	strcat(path, _path+1);
     }
     else {
-	path=malloc(strlen(_path)+NAME_MAX+1);	if(!path) return 0;
+	path=PR_Malloc(strlen(_path)+NAME_MAX+1);	if(!path) return 0;
         strcpy(path, _path);
     }
     return path;
@@ -96,14 +96,14 @@ char *get_mime_list()
     char *path=0;
     int listlen=0,	i;
 
-    if(!mimelist) mimelist=malloc(PSIZE);	if(!mimelist) return mimelist;
+    if(!mimelist) mimelist=PR_Malloc(PSIZE);	if(!mimelist) return mimelist;
     mimelist[0]=0;
     for(i=sizeof slavedirs/sizeof slavedirs[0]; i-- ;) {
-	if(path)free(path);
+	if(path)PR_Free(path);
 	path=strpath(slavedirs[i]);	if(!path) continue;
 	if(listdir(&mimelist,&listlen,&path,strlen(path),0, 1))	break;
     }
-    if(path)free(path);
+    if(path)PR_Free(path);
     return mimelist;    
 }
 
@@ -113,7 +113,7 @@ char *find_slave(char *mime)
     int	i;
 
     for(i=sizeof slavedirs/sizeof slavedirs[0]; i-- ;) {
-	if(path)free(path);
+	if(path)PR_Free(path);
 	path=strpath(slavedirs[i]);	if(!path) continue;
 	strncat(path,mime,NAME_MAX);
 	if( access(path,X_OK)==0 )	return path;
