@@ -1,4 +1,4 @@
-// $Id: threadqueue.cpp,v 1.4 2006/03/15 19:23:04 khlut Exp $
+// $Id: threadqueue.cpp,v 1.5 2006/03/22 21:02:09 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -28,11 +28,10 @@ static NS_DEFINE_CID( kEventQueueService, NS_EVENTQUEUESERVICE_CID );
 extern "C" void PR_CALLBACK DestroyEvent(PLEvent* event) ;                                                                                   
 extern "C" void * PR_CALLBACK HandleEvent(PLEvent* event) ;
 
-nsIEventQueueService * eventQService=0;
+nsIServiceManager * SM = 0;
 
 extern "C" void init_qservice(nsISupports *nss)
 {
-    nsIServiceManager * SM = 0;
 
     if(!nss)	return;
 
@@ -43,18 +42,24 @@ extern "C" void init_qservice(nsISupports *nss)
         printf("Unable to get service manager!\n");	return;
     }
 
-    SM->GetService(kEventQueueService, NS_GET_IID(nsIEventQueueService), (void **)&eventQService);
-    NS_RELEASE(SM);
-
-    if(!eventQService) {
-        printf("Unable to get event queue service!\n");	return;
-    }
 }
 extern "C" void shut_qservice()
 {
-    NS_IF_RELEASE(eventQService);
+    NS_IF_RELEASE(SM);
     return;
 }
+static nsIEventQueue * GetEventQ(PRThread *receiver)
+{
+    nsIEventQueue *eventQ=0;
+    nsIEventQueueService * eventQService=0;
+  if(!SM)return eventQ;    
+    SM->GetService(kEventQueueService, NS_GET_IID(nsIEventQueueService), (void **)&eventQService);
+  if(!eventQService)return eventQ;
+    eventQService->GetThreadEventQueue(receiver,&eventQ);
+    NS_IF_RELEASE(eventQService);
+  return eventQ;
+}
+
 
 extern "C" bool post_event_to_thread( PRThread *receiver, PLEvent *(*allocator)(void * owner, const void * msg), 
 void * owner, const void * msg )
@@ -62,12 +67,9 @@ void * owner, const void * msg )
     bool r=true;
     PLEvent * event;
 
-    if(!eventQService)		return false;
+    nsIEventQueue *eventQ=GetEventQ(receiver);
+    if(!eventQ) { printf("Unable to get thread queue!\n");	return false;}
 
-    nsCOMPtr<nsIEventQueue> eventQ;
-    if(NS_FAILED( eventQService->GetThreadEventQueue(receiver,getter_AddRefs(eventQ)) )) {
-	return false;
-    }
     eventQ->EnterMonitor();
     if((event=(*allocator)(owner, msg)))
       if(NS_FAILED( eventQ->PostEvent(event) )) {
@@ -76,6 +78,7 @@ void * owner, const void * msg )
       }
     eventQ->ExitMonitor();
 
+    NS_IF_RELEASE(eventQ);
     return r;
 }
 
@@ -90,22 +93,17 @@ extern "C" bool process_pending_events(void *owner)
 {
     // Get the event queue of the current thread...
 
-    if(!eventQService)		return false;
-
-    nsCOMPtr<nsIEventQueue> eventQ=0;
-     
-    if(NS_FAILED( eventQService->GetThreadEventQueue(PR_GetCurrentThread(),getter_AddRefs(eventQ)) )) {
-        printf("Unable to get thread queue!\n");
-        return false;
-    }
-
+    nsIEventQueue *eventQ=GetEventQ(PR_GetCurrentThread());
+    if(!eventQ) { printf("Unable to get thread queue!\n");	return false;}
     PLEventQueue *PLEQ=0;
     eventQ->GetPLEventQueue(&PLEQ);
-    if(!PLEQ) return false;
+
+    if(!PLEQ) { NS_IF_RELEASE(eventQ); printf("Unable to get PLEventQueue!\n"); return false; }
 
     eventQ->EnterMonitor();
     PL_MapEvents(PLEQ,&ProcessOwnerEvents, owner);
     eventQ->ExitMonitor();
     
+    NS_IF_RELEASE(eventQ);
     return true;
 }
